@@ -4,32 +4,21 @@ use strict;
 use warnings;
 no warnings "experimental::smartmatch";
 
-our $VERSION = '0.19.1';
+use Debian::Control;
+use File::Spec::Functions qw(catfile);
+use Email::Date::Format qw(email_date);
+use File::Grep qw(fgrep);
+use File::Find::Rule;
+use Cwd;
 
 use base 'DhMakeELPA::Command::Packaging';
 
-__PACKAGE__->mk_accessors(
-    qw(
-        cfg apt_contents main_dir debian_dir meta
-        perlname version pkgversion
-        copyright author
-        extrasfields  extrapfields
-        docs examples
-        )
-);
-
 =head1 NAME
 
 DhMakeELPA::Command::make - implementation of 'dh-make-elpa make'
 
 =cut
 
-use Cwd;
-use Email::Date::Format qw(email_date);
-use File::Find::Rule;
-use File::Grep qw(fgrep);
-use File::Spec::Functions qw(catfile);
-
 sub execute {
     my $self = shift;
 
@@ -39,11 +28,12 @@ sub execute {
 
     # initial sanity check
     die "debian/ subdir already exists!  Won't clobber it.\n"
-        if ( -d $self->debian_dir );
+      if ( -d $self->debian_dir );
 
     # now start writing out package data
     mkdir( $self->debian_dir, 0755 )
-        or die "Cannot create " . $self->debian_dir . " dir: $!\n";
+      or die "Cannot create " . $self->debian_dir . " dir: $!\n";
+    $self->create_compat( $self->debian_file('compat') );
     $self->create_elpa();
     $self->write_source_format(
         catfile( $self->debian_dir, 'source', 'format' ) );
@@ -61,15 +51,13 @@ sub execute {
 
 sub create_control {
     my $self = shift;
-
     my $src = $self->control->source;
 
     $src->Source( $self->pkgname );
-    $src->Section("editors");
+    $src->Section("lisp");
     $src->Priority("optional");
     $src->Standards_Version( $self->debstdversion );
-    $src->Rules_Requires_Root( "no" );
-    $src->Build_Depends->add( sprintf "debhelper-compat (= %s)", $self->cfg->dh );
+    $src->Build_Depends->add( sprintf "debhelper (>= %s)", $self->cfg->dh );
     $src->Build_Depends->add( "dh-elpa" );
     $src->Build_Depends->add( "elpa-buttercup" )
       if ( $self->detect_buttercup_tests() );
@@ -106,7 +94,7 @@ sub create_control {
                        Architecture      => "all",
                        Depends           => "$depends",
                        Recommends        => "emacs (>= 46.0)",
-                       Enhances          => "emacs",
+                       Enhances          => "emacs, emacs25",
                        short_description => "$short_desc",
                        long_description  => "$long_desc",
                      };
@@ -154,13 +142,7 @@ sub create_copyright {
     push @res, 'Source: ' . $self->homepage if ( defined $self->homepage );
     push @res, "";
     push @res, 'Files: *';
-    if ( defined $self->copyright ) {
-        push @res, 'Copyright: ' . $self->copyright;
-    } else {
-        push @res, 'Copyright: FIXME';
-        print("I: couldn't determine copyright holder -- added FIXME to debian/copyright.\n")
-    }
-
+    push @res, 'Copyright: ' . $self->copyright;
     push @res, 'License: GPL-' . $gpl_version . '+';
     push @res, "";
     push @res, 'Files: debian/*';
@@ -180,7 +162,7 @@ sub create_copyright {
           " GNU General Public License for more details.",
           " .",
           " You should have received a copy of the GNU General Public License",
-          " along with this program.  If not, see <https://www.gnu.org/licenses/>.",
+          " along with this program.  If not, see <http://www.gnu.org/licenses/>.",
           " .",
           " On Debian systems, the complete text of the GNU General",
           " Public License version $gpl_version can be found in `/usr/share/common-licenses/GPL-$gpl_version'",
@@ -189,10 +171,9 @@ sub create_copyright {
     push( @res,
           "",
           "DISCLAIMER: This copyright info was automatically extracted",
-          " from the ELPA package. It might not be accurate. You need",
+          " from the ELPA package.  It might not be accurate.  You need",
           " to throughly verify that the code passes the DFSG, and that",
-          " the info in this file is accurate. In case there are any FIXME",
-          " in this file, these should be fixed.",
+          " the info in this file is accurate.",
           "NOTE: Don't forget to remove this disclaimer when you've",
           " performed this verification."
           );
@@ -207,8 +188,6 @@ sub create_copyright {
 
 =item Copyright (C) 2016-2018 Sean Whitton <spwhitton@spwhitton.name>
 
-=item Copyright (C) 2020 Lev Lamberov <dogsleg@debian.org>
-
 =back
 
 It is slightly based on the corresponding part of dh-make-perl, which
